@@ -348,6 +348,8 @@ static struct gbproxy_bvc *gbproxy_select_sgsn_bvc(struct gbproxy_config *cfg, s
 			continue;
 		if (sgsn->nse != sgsn_bvc->nse)
 			continue;
+		if (!bssgp_bvc_fsm_is_unblocked(sgsn_bvc->fi))
+			continue;
 
 		return sgsn_bvc;
 	}
@@ -388,7 +390,7 @@ static int gbproxy_decode_bssgp(const struct bssgp_normal_hdr *bgph, int msg_len
 	if (bgph->pdu_type == BSSGP_PDUT_UL_UNITDATA || bgph->pdu_type == BSSGP_PDUT_DL_UNITDATA) {
 		const struct bssgp_ud_hdr *budh = (struct bssgp_ud_hdr *) bgph;
 		if (msg_len < sizeof(*budh))
-			return -OSMO_TLVP_ERR_MAND_IE_MISSING;
+			return OSMO_TLVP_ERR_MAND_IE_MISSING;
 		rc = osmo_tlv_prot_parse(&osmo_pdef_bssgp, tp, 1, budh->pdu_type, budh->data,
 					 msg_len - sizeof(*budh), 0, 0, DGPRS, log_pfx);
 		/* populate TLLI from the fixed headser into the TLV-parsed array so later code
@@ -530,6 +532,9 @@ static int gbprox_rx_ptp_from_bss(struct gbproxy_nse *nse, struct msgb *msg, uin
 	}
 	}
 
+	if (rc < 0)
+		rate_ctr_inc(rate_ctr_group_get_ctr(bss_bvc->ctrg, GBPROX_PEER_CTR_FWD_FROM_BSS_ERR));
+
 	return 0;
 }
 
@@ -604,8 +609,12 @@ static int gbprox_rx_ptp_from_sgsn(struct gbproxy_nse *nse, struct msgb *msg, ui
 	default:
 		break;
 	}
-	return gbprox_relay2peer(msg, bss_bvc, bss_bvc->bvci);
+	rc = gbprox_relay2peer(msg, bss_bvc, bss_bvc->bvci);
 
+	if (rc < 0)
+		rate_ctr_inc(rate_ctr_group_get_ctr(bss_bvc->ctrg, GBPROX_PEER_CTR_FWD_FROM_SGSN_ERR));
+
+	return rc;
 }
 
 /***********************************************************************
@@ -682,8 +691,10 @@ static void bss_ptp_bvc_reset_notif(uint16_t nsei, uint16_t bvci, const struct g
 				LOGPBVC(bvc->cell->bss_bvc, LOGL_NOTICE, "Destroying due to conflicting "
 					"BVCI configuration (new NSEI=%05u)!\n", bvc->nse->nsei);
 				gbproxy_bvc_free(bvc->cell->bss_bvc);
+				bvc->cell = NULL;
+			} else {
+				LOGPBVC(bvc, LOGL_ERROR, "Found cell without BSS BVC, this should not happen!");
 			}
-			bvc->cell->bss_bvc = bvc;
 		}
 	}
 
@@ -837,6 +848,7 @@ static void sgsn_sig_bvc_reset_notif(uint16_t nsei, uint16_t bvci, const struct
 
 const struct bssgp_bvc_fsm_ops sgsn_sig_bvc_fsm_ops = {
 	.reset_notification = sgsn_sig_bvc_reset_notif,
+	.reset_ack_notification = sgsn_sig_bvc_reset_notif,
 };
 
 /***********************************************************************
@@ -982,9 +994,9 @@ static int gbproxy_tlli_from_status_pdu(struct tlv_parsed *tp, uint32_t *tlli, c
 	struct bssgp_normal_hdr *bgph = (struct bssgp_normal_hdr *)pdu_data;
 	struct tlv_parsed tp_inner;
 
-	/* TODO: Parse partial messages as well */
 	rc = gbproxy_decode_bssgp(bgph, pdu_len, &tp_inner, log_pfx);
-	if (rc < 0)
+	/* Ignore decode failure due to truncated message */
+	if (rc < 0 && rc != OSMO_TLVP_ERR_OFS_BEYOND_BUFFER)
 		return rc;
 
 	if (TLVP_PRESENT(&tp_inner, BSSGP_IE_TLLI)) {
@@ -1010,9 +1022,9 @@ static int gbproxy_bvci_from_status_pdu(struct tlv_parsed *tp, uint16_t *bvci, c
 	struct bssgp_normal_hdr *bgph = (struct bssgp_normal_hdr *)pdu_data;
 	struct tlv_parsed tp_inner;
 
-	/* TODO: Parse partial messages as well */
 	rc = gbproxy_decode_bssgp(bgph, pdu_len, &tp_inner, log_pfx);
-	if (rc < 0)
+	/* Ignore decode failure due to truncated message */
+	if (rc < 0 && rc != OSMO_TLVP_ERR_OFS_BEYOND_BUFFER)
 		return rc;
 
 	if (TLVP_PRESENT(&tp_inner, BSSGP_IE_BVCI))
@@ -1151,15 +1163,27 @@ static int gbprox_rx_sig_from_bss(struct gbproxy_nse *nse, struct msgb *msg, uin
 		rc = gbprox_rx_rim_from_bss(tp, nse, msg, log_pfx, pdut_name);
 		break;
 	case BSSGP_PDUT_LLC_DISCARD:
-	case BSSGP_PDUT_FLUSH_LL_ACK:
 		/* route based on BVCI + TLLI */
 		ptp_bvci = ntohs(tlvp_val16_unal(&tp[0], BSSGP_IE_BVCI));
 		tlli = osmo_load32be(TLVP_VAL(&tp[0], BSSGP_IE_TLLI));
 		from_bvc = gbproxy_bvc_by_bvci(nse, ptp_bvci);
 		if (!from_bvc)
 			goto err_no_bvc;
-		gbprox_bss2sgsn_tlli(from_bvc->cell, msg, &tlli, true);
+		rc = gbprox_bss2sgsn_tlli(from_bvc->cell, msg, &tlli, true);
 		break;
+	case BSSGP_PDUT_FLUSH_LL_ACK:
+	{
+		/* Route based on TLLI */
+		tlli = osmo_load32be(TLVP_VAL(&tp[0], BSSGP_IE_TLLI));
+		struct gbproxy_sgsn *sgsn = gbproxy_select_sgsn(nse->cfg, &tlli);
+		if (!sgsn) {
+			rc = -EINVAL;
+			break;
+		}
+
+		rc = gbprox_relay2nse(msg, sgsn->nse, 0);
+		break;
+	}
 	case BSSGP_PDUT_PAGING_PS_REJECT:
 	case BSSGP_PDUT_DUMMY_PAGING_PS_RESP:
 	{
@@ -1459,6 +1483,10 @@ static int gbprox_rx_sig_from_sgsn(struct gbproxy_nse *nse, struct msgb *msg, ui
 		rc = osmo_fsm_inst_dispatch(sgsn_bvc->fi, BSSGP_BVCFSM_E_RX_UNBLOCK_ACK, msg);
 		break;
 	case BSSGP_PDUT_FLUSH_LL:
+		/* TODO: If new BVCI is on different NSE we should remove the new BVCI so the
+		 * message is interpreted as a request to delete the PDUs, not forward them.
+		 * If we negotiate Inter-NSE re-routing or LCS-procedures we can also
+		 * add the NSEI TLV to trigger re-routing the PDUs */
 		/* simple case: BVCI IE is mandatory */
 		bvci = ntohs(tlvp_val16_unal(&tp[0], BSSGP_IE_BVCI));
 		sgsn_bvc = gbproxy_bvc_by_bvci(nse, bvci);
