@@ -43,7 +43,7 @@
 #include <osmocom/gprs/gprs_bssgp.h>
 
 #include "debug.h"
-#include <osmocom/sgsn/gb_proxy.h>
+#include <osmocom/gbproxy/gb_proxy.h>
 
 #include <osmocom/ctrl/control_vty.h>
 #include <osmocom/ctrl/control_if.h>
@@ -55,6 +55,7 @@
 #include <osmocom/vty/stats.h>
 #include <osmocom/vty/ports.h>
 #include <osmocom/vty/misc.h>
+#include <osmocom/vty/cpu_sched_vty.h>
 
 #include "../bscconfig.h"
 
@@ -116,7 +117,7 @@ static void signal_handler(int signum)
 
 static void print_usage()
 {
-	printf("Usage: bsc_hack\n");
+	printf("Usage: osmo-gbproxy\n");
 }
 
 static void print_help()
@@ -265,7 +266,7 @@ int main(int argc, char **argv)
 	int rc;
 	struct ctrl_handle *ctrl;
 
-	tall_sgsn_ctx = talloc_named_const(NULL, 0, "nsip_proxy");
+	tall_sgsn_ctx = talloc_named_const(NULL, 0, "gb_proxy");
 	msgb_talloc_ctx_init(tall_sgsn_ctx, 0);
 	vty_info.tall_ctx = tall_sgsn_ctx;
 
@@ -285,25 +286,9 @@ int main(int argc, char **argv)
 	osmo_talloc_vty_add_cmds();
 	osmo_stats_vty_add_cmds();
 	osmo_fsm_vty_add_cmds();
+	osmo_cpu_sched_vty_init(tall_sgsn_ctx);
 	gbproxy_vty_init();
 
-	handle_options(argc, argv);
-
-	/* Backwards compatibility: for years, the default config file name was
-	 * osmo_gbproxy.cfg. All other Osmocom programs use osmo-*.cfg with a
-	 * dash. To be able to use the new config file name without breaking
-	 * previous setups that might rely on the legacy default config file
-	 * name, we need to look for the old config file if no -c option was
-	 * passed AND no file exists with the new default file name. */
-	if (!config_file) {
-		/* No -c option was passed */
-		if (file_exists(CONFIG_FILE_LEGACY)
-		    && !file_exists(CONFIG_FILE_DEFAULT))
-			config_file = CONFIG_FILE_LEGACY;
-		else
-			config_file = CONFIG_FILE_DEFAULT;
-	}
-
 	rate_ctr_init(tall_sgsn_ctx);
 	osmo_stats_init(tall_sgsn_ctx);
 
@@ -321,6 +306,23 @@ int main(int argc, char **argv)
 	gprs_ns2_vty_init(gbcfg->nsi);
 	logging_vty_add_deprecated_subsys(tall_sgsn_ctx, "bssgp");
 
+	handle_options(argc, argv);
+
+	/* Backwards compatibility: for years, the default config file name was
+	 * osmo_gbproxy.cfg. All other Osmocom programs use osmo-*.cfg with a
+	 * dash. To be able to use the new config file name without breaking
+	 * previous setups that might rely on the legacy default config file
+	 * name, we need to look for the old config file if no -c option was
+	 * passed AND no file exists with the new default file name. */
+	if (!config_file) {
+		/* No -c option was passed */
+		if (file_exists(CONFIG_FILE_LEGACY)
+		    && !file_exists(CONFIG_FILE_DEFAULT))
+			config_file = CONFIG_FILE_LEGACY;
+		else
+			config_file = CONFIG_FILE_DEFAULT;
+	}
+
 	bssgp_set_bssgp_callback(gbprox_bssgp_send_cb, gbcfg);
 
 	rc = gbproxy_parse_config(config_file, gbcfg);
