@@ -39,7 +39,7 @@
 #include <osmocom/gsm/gsm48.h>
 
 #include "debug.h"
-#include <osmocom/sgsn/gb_proxy.h>
+#include <osmocom/gbproxy/gb_proxy.h>
 
 #include <osmocom/vty/command.h>
 #include <osmocom/vty/logging.h>
@@ -82,8 +82,9 @@ static void gbprox_vty_print_bvc(struct vty *vty, struct gbproxy_bvc *bvc)
 		vty_out(vty, "NSEI %5u, SIG-BVCI %5u [%s]%s", bvc->nse->nsei, bvc->bvci,
 			osmo_fsm_inst_state_name(bvc->fi), VTY_NEWLINE);
 	} else {
-		vty_out(vty, "NSEI %5u, PTP-BVCI %5u, RAI %s [%s]%s", bvc->nse->nsei, bvc->bvci,
-			osmo_rai_name(&bvc->cell->id.raid), osmo_fsm_inst_state_name(bvc->fi), VTY_NEWLINE);
+		vty_out(vty, "NSEI %5u, PTP-BVCI %5u, RAI %s, CellID %u [%s]%s", bvc->nse->nsei,
+			bvc->bvci, osmo_rai_name(&bvc->cell->id.raid), bvc->cell->id.cid,
+			osmo_fsm_inst_state_name(bvc->fi), VTY_NEWLINE);
 	}
 }
 
@@ -543,21 +544,6 @@ DEFUN(show_gbproxy_cell, show_gbproxy_cell_cmd, "show gbproxy cell [stats]",
 	return CMD_SUCCESS;
 }
 
-DEFUN(show_gbproxy_links, show_gbproxy_links_cmd, "show gbproxy links",
-       SHOW_STR GBPROXY_STR "Show logical links\n")
-{
-	struct gbproxy_nse *nse;
-	int i, j;
-
-	hash_for_each(g_cfg->bss_nses, i, nse, list) {
-		struct gbproxy_bvc *bvc;
-		hash_for_each(nse->bvcs, j, bvc, list) {
-			gbprox_vty_print_bvc(vty, bvc);
-		}
-	}
-	return CMD_SUCCESS;
-}
-
 DEFUN(show_gbproxy_tlli_cache, show_gbproxy_tlli_cache_cmd,
       "show gbproxy tlli-cache",
       SHOW_STR GBPROXY_STR "Show TLLI cache entries\n")
@@ -737,7 +723,6 @@ int gbproxy_vty_init(void)
 {
 	install_element_ve(&show_gbproxy_bvc_cmd);
 	install_element_ve(&show_gbproxy_cell_cmd);
-	install_element_ve(&show_gbproxy_links_cmd);
 	install_element_ve(&show_gbproxy_tlli_cache_cmd);
 	install_element_ve(&show_gbproxy_imsi_cache_cmd);
 	install_element_ve(&show_nri_all_cmd);
